Documentation
¶
Overview ¶
Package gomamayo provides checking a term if it is Gomamayo.
How to Use ¶
You can check if a term is Gomamayo with Analyze function, like below.
g, err := gomamayo.Init()
if err != nil {
panic(err)
}
result := g.Analyze("ゴママヨサラダ")
if result.IsGomamayo {
fmt.Println("This is Gomamayo")
} else {
fmt.Println("This is not Gomamayo")
}
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GoMamayo ¶
func Init ¶
Set dictionary. You must do this first. Set dictionary you like. You can use a Kagome Dictionary. https://github.com/ikawaha/kagome#dictionaries
Click to show internal directories.
Click to hide internal directories.